@@ -27,7 +27,7 @@ from ._deb822 import PkgRelation
 
 from .reformatting import (
     check_generated_file,
-    check_preserve_formatting,
+    edit_formatted_file,
     )
 
 
@@ -35,6 +35,25 @@ class FormattingUnpreservable(Exception):
     """Formatting unpreservable."""
 
 
+def dump_paragraphs(paragraphs):
+    """Dump a set of deb822 paragraphs to a file.
+
+    Args:
+      paragraphs: iterable over paragraphs
+    Returns:
+      formatted text (as bytes)
+    """
+    outf = BytesIO()
+    first = True
+    for paragraph in paragraphs:
+        if paragraph:
+            if not first:
+                outf.write(b'\n')
+            paragraph.dump(fd=outf, encoding='utf-8')
+            first = False
+    return outf.getvalue()
+
+
 def reformat_deb822(contents):
     """Check whether it's possible to preserve a control file.
 
@@ -43,12 +62,8 @@ def reformat_deb822(contents):
     Returns:
       New contents
     """
-    outf = BytesIO()
-    for paragraph in Deb822.iter_paragraphs(BytesIO(contents),
-                                            encoding='utf-8'):
-        paragraph.dump(fd=outf, encoding='utf-8')
-        outf.write(b'\n')
-    return outf.getvalue()
+    return dump_paragraphs(
+        Deb822.iter_paragraphs(BytesIO(contents), encoding='utf-8'))
 
 
 def update_control(path='debian/control', **kwargs):
@@ -68,17 +83,11 @@ def update_control(path='debian/control', **kwargs):
     with open(path, 'rb') as f:
         original_contents = f.read()
     rewritten_contents = reformat_deb822(original_contents)
-    check_preserve_formatting(
-        rewritten_contents.strip(), original_contents.strip(),
-        path)
     outf = BytesIO()
     update_control_file(BytesIO(original_contents), outf, **kwargs)
     updated_contents = outf.getvalue()
-    if updated_contents.strip() != original_contents.strip():
-        with open(path, 'wb') as f:
-            f.write(updated_contents)
-        return True
-    return False
+    return edit_formatted_file(
+        path, original_contents, rewritten_contents, updated_contents)
 
 
 def update_control_file(inf, outf, source_package_cb=None,
@@ -94,7 +103,7 @@ def update_control_file(inf, outf, source_package_cb=None,
       source_package_cb: Called on source package paragraph (optional)
       binary_package_cb: Called on each binary package paragraph (optional)
     """
-    first = True
+    paragraphs = []
     for paragraph in Deb822.iter_paragraphs(inf, encoding='utf-8'):
         if paragraph.get("Source"):
             if source_package_cb is not None:
@@ -102,11 +111,8 @@ def update_control_file(inf, outf, source_package_cb=None,
         else:
             if binary_package_cb is not None:
                 binary_package_cb(paragraph)
-        if paragraph:
-            if not first:
-                outf.write(b'\n')
-            paragraph.dump(fd=outf, encoding='utf-8')
-            first = False
+        paragraphs.append(paragraph)
+    outf.write(dump_paragraphs(paragraphs))
 
 
 def parse_relations(text):
