@@ -27,25 +27,19 @@ from debian.copyright import (
     NotMachineReadableError,
     )
 
-from .reformatting import check_preserve_formatting
+from .reformatting import edit_formatted_file
 
 
-def update_copyright(update_cb):
-    with open('debian/copyright', 'r') as f:
+def update_copyright(update_cb, path='debian/copyright'):
+    with open(path, 'r') as f:
         orig_content = f.read()
 
     copyright = Copyright(orig_content)
     rewritten_content = copyright.dump()
-    check_preserve_formatting(
-        rewritten_content.rstrip('\n'), orig_content.rstrip('\n'),
-        'debian/copyright')
 
     update_cb(copyright)
 
-    new_content = copyright.dump()
+    updated_content = copyright.dump()
 
-    if new_content.rstrip('\n') != rewritten_content.rstrip('\n'):
-        with open('debian/copyright', 'w') as f:
-            f.write(new_content)
-        return True
-    return False
+    return edit_formatted_file(
+        path, orig_content, rewritten_content, updated_content)
