@@ -29,6 +29,9 @@ def test_suite():
         'run',
         'salsa',
         'systemd',
+        'upstream_metadata',
+        'vcs',
+        'watch',
         ]
     module_names = [__name__ + '.test_' + name for name in names]
     module_names.append(__name__ + ".fixers.test_suite")
