@@ -23,19 +23,27 @@ import subprocess
 import tempfile
 from urllib.parse import urlparse
 from warnings import warn
-from lintian_brush.vcs import sanitize_url as sanitize_vcs_url
+from lintian_brush.vcs import (
+    sanitize_url as sanitize_vcs_url,
+    )
 from lintian_brush.watch import parse_watch_file
 
 
 KNOWN_HOSTING_SITES = [
-    'github.com', 'gitlab.com', 'launchpad.net', 'salsa.debian.org']
+    'code.launchpad.net', 'github.com', 'gitlab.com', 'launchpad.net',
+    'salsa.debian.org']
 
 
 def guess_repo_from_url(url):
     parsed_url = urlparse(url)
     if parsed_url.netloc == 'github.com':
+        if parsed_url.path.strip('/').count('/') < 1:
+            return None
         return ('https://github.com' +
                 '/'.join(parsed_url.path.split('/')[:3]))
+    if parsed_url.netloc == 'launchpad.net':
+        return 'https://code.launchpad.net/%s' % (
+            parsed_url.path.strip('/').split('/')[0])
     if parsed_url.netloc in KNOWN_HOSTING_SITES:
         return url
     return None
