@@ -17,8 +17,14 @@
 
 """Functions for working with watch files."""
 
+from io import StringIO
 import re
 
+from lintian_brush.reformatting import (
+    check_generated_file,
+    edit_formatted_file,
+    )
+
 
 DEFAULT_VERSION = 4
 
@@ -51,7 +57,7 @@ class WatchFile(object):
                 f.write(serialize_options(entry.options) + ' ')
             f.write(entry.url)
             if entry.matching_pattern:
-                f.write(+ ' ' + entry.matching_pattern)
+                f.write(' ' + entry.matching_pattern)
             if entry.version:
                 f.write(' ' + entry.version)
             if entry.script:
@@ -161,3 +167,24 @@ def parse_watch_file(f):
             entries.append(Watch(url, *parts, opts=opts))
     return WatchFile(
         entries=entries, options=persistent_options, version=version)
+
+
+def update_watch(update_entry=None, path='debian/watch'):
+    check_generated_file(path)
+    try:
+        with open(path, 'r') as f:
+            original_contents = f.read()
+    except FileNotFoundError:
+        return False
+    wf = parse_watch_file(original_contents.splitlines())
+    nf = StringIO()
+    wf.dump(nf)
+    rewritten_contents = nf.getvalue()
+    for entry in wf.entries:
+        if update_entry is not None:
+            update_entry(entry)
+    nf = StringIO()
+    wf.dump(nf)
+    updated_contents = nf.getvalue()
+    return edit_formatted_file(
+        path, original_contents, rewritten_contents, updated_contents)
